# Vardef Forvaltning
Vardef Forvaltning gjør det enkelt å opprette og vedlikeholde variabeldefinisjoner.

All nødvendig dokumentasjon er samlet under.

## Hvordan bruke Vardef Forvaltning

### Generell bruk
[Daplamanualen - Vardef forvaltning](https://manual.dapla.ssb.no/statistikkere/vardef-forvaltning.html)

### Arbeide med Yaml-filer
[Daplamanualen - Arbeide med Yaml-filer](https://manual.dapla.ssb.no/statistikkere/vardef-forvaltning.html#arbeide-med-yaml-filer)


## Innhold og kvalitet – Vardef-modell
Her finner du alt om felter, forventede verdier og kvalitetskrav:
- [Daplamanualen - Vardef](https://manual.dapla.ssb.no/statistikkere/vardef.html)
- [Daplamanualen - Vardef - Datamodell](https://manual.dapla.ssb.no/statistikkere/vardef-model.html)


## Lenker til Klass
- [Klass - forside](https://www.ssb.no/klass/)
- [Enhetstyper - lenke til kodeliste 702](https://www.ssb.no/klass/klassifikasjoner/702)
- [Statistikkområder - lenke til kodeliste 618](https://www.ssb.no/klass/klassifikasjoner/618)
- [Måletyper og måleenheter - lenke til kodeliste 303](https://www.ssb.no/klass/klassifikasjoner/303)

## SSB Dataportal
- [SSB Dataportal - test](https://dataportal.test.ssb.no/)
- [SSB Dataportal - prod](https://dataportal.ssb.no/)
